==> uptime_x-0.0.2.tar.gz: example/ios/Runner/AppDelegate.swift <==
import UIKit
import Flutter

@UIApplicationMain
@objc class AppDelegate: FlutterAppDelegate {
  override func application(
    _ application: UIApplication,
    didFinishLaunchingWithOptions launchOptions: [UIApplicationLaunchOptionsKey: Any]?
  ) -> Bool {
    let controller : FlutterViewController = window?.rootViewController as! FlutterViewController
    let uptimeChannel = FlutterMethodChannel(name:"uptime_x",
                                              binaryMessager: controller)

    uptimeChannel.setMethodCallHandler({
     [weak self] (call: FlutterMethodChannel, result: FlutterResult) -> Void in
      guard call.method == "uptime_x" else {
        result(FlutterMethodChannel)
        return
      }
      self?.uptime(result: result)
    })
    GeneratedPluginRegistrant.register(with: self)
    return super.application(application, didFinishLaunchingWithOptions: launchOptions)
  }

  private func uptime(result: FlutterResult) -> time_t {
    var boottime = timeval()
    var mib: [Int32] = [CTL_KERN, KERN_BOOTTIME]
    var size = strideof(timeval)

    var now = time_t()
    var uptime: time_t = -1

    time(&now)
    if (sysctl(&mib, 2, &boottime, &size, nil, 0) != -1 && boottime.tv_sec != 0) {
        uptime = now - boottime.tv_sec
    }
    if device.batteryState == UIDeviceBatteryState.unknown {
    result(FlutterError(code: "UNAVAILABLE",
                        message: "Uptime info unavailable",
                        details: nil))
  } else {
    result(Int(uptime))
  }
}
}

==> uptime_x-0.0.7.tar.gz: example/ios/Runner/AppDelegate.swift <==
import UIKit
import Flutter

@UIApplicationMain
@objc class AppDelegate: FlutterAppDelegate {
  override func application(
    _ application: UIApplication,
    didFinishLaunchingWithOptions launchOptions: [UIApplicationLaunchOptionsKey: Any]?
  ) -> Bool {
    let controller : FlutterViewController = window?.rootViewController as! FlutterViewController
    let uptimeChannel = FlutterMethodChannel(name:"uptime_x",
                                              binaryMessager: controller)

    uptimeChannel.setMethodCallHandler({
     [weak self] (call: FlutterMethodChannel, result: FlutterResult) -> Void in
      guard call.method == "getUptime" else {
        result(FlutterMethodChannel)
        return
      }
      self?.uptime(result: result)
    })
    GeneratedPluginRegistrant.register(with: self)
    return super.application(application, didFinishLaunchingWithOptions: launchOptions)
  }

  private func uptime(result: FlutterResult) -> time_t {
    var boottime = timeval()
    var mib: [Int32] = [CTL_KERN, KERN_BOOTTIME]
    var size = strideof(timeval)

    var now = time_t()
    var uptime: time_t = -1

    time(&now)
    if (sysctl(&mib, 2, &boottime, &size, nil, 0) != -1 && boottime.tv_sec != 0) {
        uptime = now - boottime.tv_sec
    }
    if device.batteryState == UIDeviceBatteryState.unknown {
    result(FlutterError(code: "UNAVAILABLE",
                        message: "Uptime info unavailable",
                        details: nil))
  } else {
    result(Int(uptime))
  }
}
}
